@@ -72,6 +72,7 @@ RenameDialog::RenameDialog(QWidget *parent, const KFileItemList& items) :
         m_newName = items.first().name();
         editLabel = new QLabel(i18nc("@label:textbox", "Rename the item <filename>%1</filename> to:", m_newName),
                                page);
+        editLabel->setTextFormat(Qt::PlainText);
     } else {
         m_newName = i18nc("@info:status", "New name #");
         editLabel = new QLabel(i18ncp("@label:textbox",
@@ -162,11 +163,6 @@ void RenameDialog::slotTextChanged(const QString& newName)
 
 void RenameDialog::renameItems()
 {
-    // Currently the items are sorted by the selection order, resort
-    // them by the filename. This assures that the new sort order is similar to
-    // the current filename sort order.
-    qSort(m_items.begin(), m_items.end(), lessThan);
-
     // Iterate through all items and rename them...
     int index = m_spinBox->value();
     foreach (const KFileItem& item, m_items) {
