@@ -30,7 +30,11 @@
 #include <QStylePainter>
 #include <QVBoxLayout>
 
+#ifndef HAVE_NEPOMUK
+#include <KFileMetaDataWidget>
+#else
 #include <nepomuk2/filemetadatawidget.h>
+#endif
 
 // For the blurred tooltip background
 #include <plasma/windoweffects.h>
@@ -51,12 +55,17 @@ FileMetaDataToolTip::FileMetaDataToolTip(QWidget* parent) :
     // Create widget for file name
     m_name = new QLabel(this);
     m_name->setForegroundRole(QPalette::ToolTipText);
+    m_name->setTextFormat(Qt::PlainText);
     QFont font = m_name->font();
     font.setBold(true);
     m_name->setFont(font);
 
     // Create widget for the meta data
+#ifndef HAVE_NEPOMUK
+    m_fileMetaDataWidget = new KFileMetaDataWidget(this);
+#else
     m_fileMetaDataWidget = new Nepomuk2::FileMetaDataWidget(this);
+#endif
     m_fileMetaDataWidget->setForegroundRole(QPalette::ToolTipText);
     m_fileMetaDataWidget->setReadOnly(true);
     connect(m_fileMetaDataWidget, SIGNAL(metaDataRequestFinished(KFileItemList)),
